from ngsolve import *
from netgen.geom2d import SplineGeometry
ngsglobals.msg_level=1

def topBottom():
    geometry = SplineGeometry()
    pnts     = [ (0, 0), (1, 0),  (1, 0.5), (1, 1), (0, 1), (0, 0.5)]
    pnums    = [geometry.AppendPoint(*p) for p in pnts]
    lines = [ (pnums[0], pnums[1], "gammaD",  2, 0),
              (pnums[1], pnums[2], "gammaD",  2, 0), 
              (pnums[2], pnums[3], "gammaS",  1, 0),
              (pnums[3], pnums[4], "gammaS",  1, 0),
              (pnums[4], pnums[5], "gammaS",  1, 0),
              (pnums[5], pnums[0], "gammaD",  2, 0),
              (pnums[5], pnums[2], "gammaSD", 1, 2)]
    for p1,p2,bc,left,right in lines:
        geometry.Append( ["line", p1, p2], bc=bc, leftdomain=left, rightdomain=right)

    geometry.SetMaterial(1, "fluid1")
    geometry.SetMaterial(2, "fluid2")
        
    return geometry

mesh = Mesh(topBottom().GenerateMesh (maxh=0.5))

Q1 = FacetFESpace(mesh, order=1, definedon=mesh.Materials("fluid1"))
Q2 = FacetFESpace(mesh, order=1, definedon=mesh.Materials("fluid2"))
X    = FESpace([Q1, Q2])
p1, p2 = X.TrialFunction()
q1, q2 = X.TestFunction()

a = BilinearForm(X, eliminate_internal=True)
interfaceTerm = 100*p1.Trace()*q1.Trace() + 100*p2.Trace()*q2.Trace()
a += SymbolicBFI(interfaceTerm, definedon=mesh.Boundaries("gammaSD"))
a.Assemble()
print("matrix: ", a.mat.data)
